#!/bin/bash



df=-1000   ##  detuning frequency (unit: Hz)  
df0=${df:0:7}
######## set up the detuning of the RF system 
freqd=499801011.2628143
freqc=`rpnl "$freqd $df +"`


nturns=5000 ##  number of tracking turns


npk=10     ##  number of particles in the tracking (unit: thousand)
nPerBunch=`rpnl "$npk 1000 *"`

ncharge=15  ## injected bunch charge(unit: nC)

charge=`rpnl "$ncharge 1e-9 *"`

###### the numerator and denominator of the RF feedback
##  no RF feedback
num1=0      
den1=1
##  proportional controller only
num2=200.0  
den2=0
######################################################

ui=20      ##  update interval of RF feedback




########## First consider the case w/o RF feedback

root=./no_feedback

####### set up RF feedback 

in_filter=${root}/in_filter.sdds
qu_filter=${root}/qu_filter.sdds

echo ${num1}","${den1} | csv2sdds  -asciiOutput \
    -col=name=numerator,type=double \
    -col=name=denominator,type=double \
    -pipe=in   $in_filter

echo ${num1}","${den1} | csv2sdds  -asciiOutput \
    -col=name=numerator,type=double \
    -col=name=denominator,type=double \
    -pipe=in   $qu_filter


rootname=${root}/track

beamfile=sto_${npk}k.sdds


elegant track.ele -macro=rootname=${rootname},nturns=${nturns},bunch=${beamfile},freqc=${freqc},ui=${ui},charge=${charge},in_filter=${in_filter},qu_filter=${qu_filter} 2>&1 | tee  ${rootname}.log 



## next consider the case w/ proportional controller

root=./proportional_feedback

####### set up RF feedback 

in_filter=${root}/in_filter.sdds
qu_filter=${root}/qu_filter.sdds

echo ${num2}","${den2} | csv2sdds  -asciiOutput \
    -col=name=numerator,type=double \
    -col=name=denominator,type=double \
    -pipe=in   $in_filter

echo ${num2}","${den2} | csv2sdds  -asciiOutput \
    -col=name=numerator,type=double \
    -col=name=denominator,type=double \
    -pipe=in   $qu_filter


rootname=${root}/track

beamfile=sto_${npk}k.sdds


elegant track.ele -macro=rootname=${rootname},nturns=${nturns},bunch=${beamfile},freqc=${freqc},ui=${ui},charge=${charge},in_filter=${in_filter},qu_filter=${qu_filter} 2>&1 | tee  ${rootname}.log 

